@@ -75,14 +75,15 @@ macro_rules! write_integer_to_vec {
 }
 
 #[derive(Debug)]
-pub struct Config {
-    pub initial_state: BTreeMap<u32, Value>,
+pub struct Config<'a> {
+    pub initial_state: BTreeMap<u32, Value<'a>>,
     pub event_processors: Vec<EventProcessor>,
 }
 
 #[derive(Debug, PartialEq)]
 pub enum ConfigSerializerError {
     WrongSize,
+    TriedToSaveReferenceValue,
     UnknownExtractor,
     UnknownFilter,
     UnknownProducer,
@@ -99,6 +100,10 @@ impl ConfigSerializer {
         for state in config.initial_state.iter() {
             write_integer_to_vec!(data, *state.0, u32);
 
+            if let Value::Reference(_) = state.1 {
+                return Err(ConfigSerializerError::TriedToSaveReferenceValue);
+            }
+
             unsafe {
                 for byte in transmute_copy::<Value, [u8; size_of::<Value>()]>(state.1).iter() {
                     data.push(*byte);
@@ -202,6 +207,13 @@ impl ConfigSerializer {
             offset,
             extractor_code
         );
+        impl_item_read!(
+            PACKET_EXTRACTOR_CODE,
+            PacketExtractor,
+            data,
+            offset,
+            extractor_code
+        );
         Err(ConfigSerializerError::UnknownExtractor)
     }
 
@@ -216,6 +228,7 @@ impl ConfigSerializer {
             data,
             extractor
         );
+        impl_item_write!(PACKET_EXTRACTOR_CODE, PacketExtractor, data, extractor);
         Err(ConfigSerializerError::UnknownExtractor)
     }
 
@@ -333,6 +346,13 @@ impl ConfigSerializer {
             offset,
             producer_code
         );
+        impl_item_read!(
+            PACKET_PRODUCER_CODE,
+            PacketProducer,
+            data,
+            offset,
+            producer_code
+        );
         Err(ConfigSerializerError::UnknownProducer)
     }
 
@@ -353,6 +373,7 @@ impl ConfigSerializer {
             data,
             producer
         );
+        impl_item_write!(PACKET_PRODUCER_CODE, PacketProducer, data, producer);
         Err(ConfigSerializerError::UnknownProducer)
     }
 }
