@@ -1,10 +1,10 @@
 use core::fmt::Debug;
-use downcast_rs::{Downcast, impl_downcast};
+use downcast_rs::{impl_downcast, Downcast};
 
 use crate::state::StateManager;
 use crate::Value;
 
-pub mod state_filter;
+pub mod state;
 
 mod u16_filter;
 pub use u16_filter::*;
