@@ -1,5 +1,7 @@
 #![no_std]
 
+use ross_protocol::packet::Packet;
+
 pub mod config;
 pub mod event_processor;
 pub mod extractor;
@@ -12,9 +14,15 @@ pub mod state;
 mod test;
 
 #[derive(Debug, PartialEq)]
-pub enum Value {
+pub enum Value<'a> {
     None,
     U8(u8),
     U16(u16),
     U32(u32),
+    Reference(ReferenceValue<'a>),
+}
+
+#[derive(Debug, PartialEq)]
+pub enum ReferenceValue<'a> {
+    Packet(&'a Packet),
 }
