@@ -14,14 +14,18 @@ pub use bcm_change_brightness_producer::*;
 mod none_producer;
 pub use none_producer::*;
 
+mod packet_producer;
+pub use packet_producer::*;
+
 pub const NONE_PRODUCER_CODE: u16 = 0x0000;
 pub const BCM_CHANGE_BRIGHTNESS_PRODUCER_CODE: u16 = 0x0001;
 pub const BCM_CHANGE_BRIGHTNESS_STATE_PRODUCER_CODE: u16 = 0x0002;
+pub const PACKET_PRODUCER_CODE: u16 = 0x0003;
 
 pub trait Producer: Downcast + Debug {
     fn produce(
         &self,
-        value: &Value,
+        value: Value,
         state_manager: &StateManager,
         device_address: u16,
     ) -> Option<Packet>;
